/****************************************************************************
** Meta object code from reading C++ file 'session.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../yakuake-26.08.0/app/session.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'session.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7SessionE_t {};
} // unnamed namespace

template <> constexpr inline auto Session::qt_create_metaobjectdata<qt_meta_tag_ZN7SessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Session",
        "titleChanged",
        "",
        "title",
        "sessionId",
        "terminalManuallyActivated",
        "Terminal*",
        "terminal",
        "keyboardInputBlocked",
        "activityDetected",
        "silenceDetected",
        "destroyed",
        "wantsBlurChanged",
        "closeTerminal",
        "terminalId",
        "focusNextTerminal",
        "focusPreviousTerminal",
        "splitAuto",
        "splitLeftRight",
        "splitTopBottom",
        "tryGrowTerminal",
        "GrowthDirection",
        "direction",
        "pixels",
        "runCommand",
        "command",
        "manageProfiles",
        "editProfile",
        "reconnectMonitorActivitySignals",
        "setActiveTerminal",
        "setTitle",
        "cleanup",
        "prepareShutdown"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(int, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 3 },
        }}),
        // Signal 'terminalManuallyActivated'
        QtMocHelpers::SignalData<void(Terminal *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'keyboardInputBlocked'
        QtMocHelpers::SignalData<void(Terminal *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'activityDetected'
        QtMocHelpers::SignalData<void(Terminal *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'silenceDetected'
        QtMocHelpers::SignalData<void(Terminal *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'destroyed'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'wantsBlurChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeTerminal'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'closeTerminal'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'focusNextTerminal'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'focusPreviousTerminal'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'splitAuto'
        QtMocHelpers::SlotData<int(int)>(17, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'splitAuto'
        QtMocHelpers::SlotData<int()>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Slot 'splitLeftRight'
        QtMocHelpers::SlotData<int(int)>(18, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'splitLeftRight'
        QtMocHelpers::SlotData<int()>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Slot 'splitTopBottom'
        QtMocHelpers::SlotData<int(int)>(19, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'splitTopBottom'
        QtMocHelpers::SlotData<int()>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Slot 'tryGrowTerminal'
        QtMocHelpers::SlotData<int(int, enum GrowthDirection, uint)>(20, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 14 }, { 0x80000000 | 21, 22 }, { QMetaType::UInt, 23 },
        }}),
        // Slot 'runCommand'
        QtMocHelpers::SlotData<void(const QString &, int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 }, { QMetaType::Int, 14 },
        }}),
        // Slot 'runCommand'
        QtMocHelpers::SlotData<void(const QString &)>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'manageProfiles'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'editProfile'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reconnectMonitorActivitySignals'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setActiveTerminal'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'setTitle'
        QtMocHelpers::SlotData<void(int, const QString &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::QString, 3 },
        }}),
        // Slot 'cleanup'
        QtMocHelpers::SlotData<void(int)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'cleanup'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'prepareShutdown'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Session, qt_meta_tag_ZN7SessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Session::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7SessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7SessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7SessionE_t>.metaTypes,
    nullptr
} };

void Session::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Session *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->terminalManuallyActivated((*reinterpret_cast<std::add_pointer_t<Terminal*>>(_a[1]))); break;
        case 3: _t->keyboardInputBlocked((*reinterpret_cast<std::add_pointer_t<Terminal*>>(_a[1]))); break;
        case 4: _t->activityDetected((*reinterpret_cast<std::add_pointer_t<Terminal*>>(_a[1]))); break;
        case 5: _t->silenceDetected((*reinterpret_cast<std::add_pointer_t<Terminal*>>(_a[1]))); break;
        case 6: _t->destroyed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->wantsBlurChanged(); break;
        case 8: _t->closeTerminal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->closeTerminal(); break;
        case 10: _t->focusNextTerminal(); break;
        case 11: _t->focusPreviousTerminal(); break;
        case 12: { int _r = _t->splitAuto((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 13: { int _r = _t->splitAuto();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->splitLeftRight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: { int _r = _t->splitLeftRight();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 16: { int _r = _t->splitTopBottom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 17: { int _r = _t->splitTopBottom();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 18: { int _r = _t->tryGrowTerminal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum GrowthDirection>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->runCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 20: _t->runCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->manageProfiles(); break;
        case 22: _t->editProfile(); break;
        case 23: _t->reconnectMonitorActivitySignals(); break;
        case 24: _t->setActiveTerminal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->setTitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 26: _t->cleanup((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->cleanup(); break;
        case 28: _t->prepareShutdown(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Session::*)(const QString & )>(_a, &Session::titleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(int , const QString & )>(_a, &Session::titleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Terminal * )>(_a, &Session::terminalManuallyActivated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Terminal * )>(_a, &Session::keyboardInputBlocked, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Terminal * )>(_a, &Session::activityDetected, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(Terminal * )>(_a, &Session::silenceDetected, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)(int )>(_a, &Session::destroyed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Session::*)()>(_a, &Session::wantsBlurChanged, 7))
            return;
    }
}

const QMetaObject *Session::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Session::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7SessionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Session::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void Session::titleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Session::titleChanged(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Session::terminalManuallyActivated(Terminal * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Session::keyboardInputBlocked(Terminal * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Session::activityDetected(Terminal * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Session::silenceDetected(Terminal * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Session::destroyed(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Session::wantsBlurChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
