/****************************************************************************
** Meta object code from reading C++ file 'tabbar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../yakuake-26.08.0/app/tabbar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tabbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6TabBarE_t {};
} // unnamed namespace

template <> constexpr inline auto TabBar::qt_create_metaobjectdata<qt_meta_tag_ZN6TabBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TabBar",
        "D-Bus Interface",
        "org.kde.yakuake",
        "newTabRequested",
        "",
        "tabSelected",
        "sessionId",
        "tabClosed",
        "requestTerminalHighlight",
        "terminalId",
        "requestRemoveTerminalHighlight",
        "tabContextMenuClosed",
        "lastTabClosed",
        "tabTitleEdited",
        "title",
        "addTab",
        "removeTab",
        "interactiveRename",
        "selectTab",
        "selectNextTab",
        "selectPreviousTab",
        "moveTabLeft",
        "moveTabRight",
        "tabTitle",
        "setTabTitle",
        "newTitle",
        "InteractiveType",
        "interactive",
        "setTabTitleAutomated",
        "sessionAtTab",
        "index",
        "readySessionMenu",
        "contextMenuActionHovered",
        "QAction*",
        "action",
        "closeTabButtonClicked",
        "interactiveRenameDone"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newTabRequested'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tabSelected'
        QtMocHelpers::SignalData<void(int)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'tabClosed'
        QtMocHelpers::SignalData<void(int)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'requestTerminalHighlight'
        QtMocHelpers::SignalData<void(int)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'requestRemoveTerminalHighlight'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tabContextMenuClosed'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastTabClosed'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tabTitleEdited'
        QtMocHelpers::SignalData<void(int, QString)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'addTab'
        QtMocHelpers::SlotData<void(int, const QString &)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'removeTab'
        QtMocHelpers::SlotData<void(int)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'removeTab'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'interactiveRename'
        QtMocHelpers::SlotData<void(int)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'selectTab'
        QtMocHelpers::SlotData<void(int)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'selectNextTab'
        QtMocHelpers::SlotData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectPreviousTab'
        QtMocHelpers::SlotData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'moveTabLeft'
        QtMocHelpers::SlotData<void(int)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'moveTabLeft'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'moveTabRight'
        QtMocHelpers::SlotData<void(int)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'moveTabRight'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'tabTitle'
        QtMocHelpers::SlotData<QString(int)>(23, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'setTabTitle'
        QtMocHelpers::SlotData<void(int, const QString &, enum InteractiveType)>(24, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::QString, 25 }, { 0x80000000 | 26, 27 },
        }}),
        // Slot 'setTabTitle'
        QtMocHelpers::SlotData<void(int, const QString &)>(24, 4, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'setTabTitleAutomated'
        QtMocHelpers::SlotData<void(int, const QString &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'sessionAtTab'
        QtMocHelpers::SlotData<int(int)>(29, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'readySessionMenu'
        QtMocHelpers::SlotData<void()>(31, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contextMenuActionHovered'
        QtMocHelpers::SlotData<void(QAction *)>(32, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'closeTabButtonClicked'
        QtMocHelpers::SlotData<void()>(35, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'interactiveRenameDone'
        QtMocHelpers::SlotData<void()>(36, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TabBar, qt_meta_tag_ZN6TabBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TabBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6TabBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6TabBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6TabBarE_t>.metaTypes,
    nullptr
} };

void TabBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TabBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newTabRequested(); break;
        case 1: _t->tabSelected((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->tabClosed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->requestTerminalHighlight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->requestRemoveTerminalHighlight(); break;
        case 5: _t->tabContextMenuClosed(); break;
        case 6: _t->lastTabClosed(); break;
        case 7: _t->tabTitleEdited((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->addTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->removeTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->removeTab(); break;
        case 11: _t->interactiveRename((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->selectTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->selectNextTab(); break;
        case 14: _t->selectPreviousTab(); break;
        case 15: _t->moveTabLeft((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->moveTabLeft(); break;
        case 17: _t->moveTabRight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->moveTabRight(); break;
        case 19: { QString _r = _t->tabTitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->setTabTitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<enum InteractiveType>>(_a[3]))); break;
        case 21: _t->setTabTitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 22: _t->setTabTitleAutomated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 23: { int _r = _t->sessionAtTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->readySessionMenu(); break;
        case 25: _t->contextMenuActionHovered((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 26: _t->closeTabButtonClicked(); break;
        case 27: _t->interactiveRenameDone(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TabBar::*)()>(_a, &TabBar::newTabRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabBar::*)(int )>(_a, &TabBar::tabSelected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabBar::*)(int )>(_a, &TabBar::tabClosed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabBar::*)(int )>(_a, &TabBar::requestTerminalHighlight, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabBar::*)()>(_a, &TabBar::requestRemoveTerminalHighlight, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabBar::*)()>(_a, &TabBar::tabContextMenuClosed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabBar::*)()>(_a, &TabBar::lastTabClosed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabBar::*)(int , QString )>(_a, &TabBar::tabTitleEdited, 7))
            return;
    }
}

const QMetaObject *TabBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TabBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6TabBarE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int TabBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void TabBar::newTabRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TabBar::tabSelected(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TabBar::tabClosed(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void TabBar::requestTerminalHighlight(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void TabBar::requestRemoveTerminalHighlight()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TabBar::tabContextMenuClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TabBar::lastTabClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void TabBar::tabTitleEdited(int _t1, QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}
QT_WARNING_POP
