/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../yakuake-26.08.0/app/mainwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindow",
        "D-Bus Interface",
        "org.kde.yakuake",
        "windowOpened",
        "",
        "windowClosed",
        "toggleWindowState",
        "handleContextDependentAction",
        "QAction*",
        "action",
        "sessionId",
        "handleContextDependentToggleAction",
        "checked",
        "handleToggleTerminalKeyboardInput",
        "handleToggleTerminalMonitorActivity",
        "handleToggleTerminalMonitorSilence",
        "handleTerminalActivity",
        "Terminal*",
        "terminal",
        "handleTerminalSilence",
        "handleLastTabClosed",
        "applySettings",
        "applySkin",
        "applyWindowProperties",
        "applyWindowGeometry",
        "setWindowGeometry",
        "width",
        "height",
        "position",
        "updateScreenMenu",
        "setScreen",
        "setWindowWidth",
        "setWindowHeight",
        "increaseWindowWidth",
        "decreaseWindowWidth",
        "increaseWindowHeight",
        "decreaseWindowHeight",
        "wmActiveWindowChanged",
        "xshapeOpenWindow",
        "xshapeRetractWindow",
        "activate",
        "toggleMousePoll",
        "poll",
        "pollMouse",
        "setKeepOpen",
        "keepOpen",
        "handleSwitchToAction",
        "handleToggleTitlebar",
        "whatsThis",
        "configureKeys",
        "configureNotifications",
        "configureApp",
        "updateTrayTooltip",
        "showFirstRunDialog",
        "firstRunDialogFinished",
        "firstRunDialogOk"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'windowOpened'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowClosed'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleWindowState'
        QtMocHelpers::SlotData<void()>(6, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Slot 'handleContextDependentAction'
        QtMocHelpers::SlotData<void(QAction *, int)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'handleContextDependentAction'
        QtMocHelpers::SlotData<void(QAction *)>(7, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'handleContextDependentAction'
        QtMocHelpers::SlotData<void()>(7, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'handleContextDependentToggleAction'
        QtMocHelpers::SlotData<void(bool, QAction *, int)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 }, { 0x80000000 | 8, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'handleContextDependentToggleAction'
        QtMocHelpers::SlotData<void(bool, QAction *)>(11, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 12 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'handleContextDependentToggleAction'
        QtMocHelpers::SlotData<void(bool)>(11, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'handleToggleTerminalKeyboardInput'
        QtMocHelpers::SlotData<void(bool)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'handleToggleTerminalMonitorActivity'
        QtMocHelpers::SlotData<void(bool)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'handleToggleTerminalMonitorSilence'
        QtMocHelpers::SlotData<void(bool)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'handleTerminalActivity'
        QtMocHelpers::SlotData<void(Terminal *)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'handleTerminalSilence'
        QtMocHelpers::SlotData<void(Terminal *)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'handleLastTabClosed'
        QtMocHelpers::SlotData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'applySettings'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'applySkin'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'applyWindowProperties'
        QtMocHelpers::SlotData<void()>(23, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'applyWindowGeometry'
        QtMocHelpers::SlotData<void()>(24, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setWindowGeometry'
        QtMocHelpers::SlotData<void(int, int, int)>(25, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 }, { QMetaType::Int, 27 }, { QMetaType::Int, 28 },
        }}),
        // Slot 'updateScreenMenu'
        QtMocHelpers::SlotData<void()>(29, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setScreen'
        QtMocHelpers::SlotData<void(QAction *)>(30, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'setWindowWidth'
        QtMocHelpers::SlotData<void(int)>(31, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'setWindowHeight'
        QtMocHelpers::SlotData<void(int)>(32, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'setWindowWidth'
        QtMocHelpers::SlotData<void(QAction *)>(31, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'setWindowHeight'
        QtMocHelpers::SlotData<void(QAction *)>(32, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'increaseWindowWidth'
        QtMocHelpers::SlotData<void()>(33, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'decreaseWindowWidth'
        QtMocHelpers::SlotData<void()>(34, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'increaseWindowHeight'
        QtMocHelpers::SlotData<void()>(35, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'decreaseWindowHeight'
        QtMocHelpers::SlotData<void()>(36, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'wmActiveWindowChanged'
        QtMocHelpers::SlotData<void()>(37, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'xshapeOpenWindow'
        QtMocHelpers::SlotData<void()>(38, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'xshapeRetractWindow'
        QtMocHelpers::SlotData<void()>(39, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'activate'
        QtMocHelpers::SlotData<void()>(40, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleMousePoll'
        QtMocHelpers::SlotData<void(bool)>(41, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'pollMouse'
        QtMocHelpers::SlotData<void()>(43, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setKeepOpen'
        QtMocHelpers::SlotData<void(bool)>(44, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'handleSwitchToAction'
        QtMocHelpers::SlotData<void()>(46, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleToggleTitlebar'
        QtMocHelpers::SlotData<void()>(47, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'whatsThis'
        QtMocHelpers::SlotData<void()>(48, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configureKeys'
        QtMocHelpers::SlotData<void()>(49, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configureNotifications'
        QtMocHelpers::SlotData<void()>(50, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configureApp'
        QtMocHelpers::SlotData<void()>(51, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateTrayTooltip'
        QtMocHelpers::SlotData<void()>(52, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showFirstRunDialog'
        QtMocHelpers::SlotData<void()>(53, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'firstRunDialogFinished'
        QtMocHelpers::SlotData<void()>(54, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'firstRunDialogOk'
        QtMocHelpers::SlotData<void()>(55, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MainWindowE_t>.metaTypes,
    nullptr
} };

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->windowOpened(); break;
        case 1: _t->windowClosed(); break;
        case 2: _t->toggleWindowState(); break;
        case 3: _t->handleContextDependentAction((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->handleContextDependentAction((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 5: _t->handleContextDependentAction(); break;
        case 6: _t->handleContextDependentToggleAction((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 7: _t->handleContextDependentToggleAction((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[2]))); break;
        case 8: _t->handleContextDependentToggleAction((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->handleToggleTerminalKeyboardInput((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->handleToggleTerminalMonitorActivity((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->handleToggleTerminalMonitorSilence((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->handleTerminalActivity((*reinterpret_cast<std::add_pointer_t<Terminal*>>(_a[1]))); break;
        case 13: _t->handleTerminalSilence((*reinterpret_cast<std::add_pointer_t<Terminal*>>(_a[1]))); break;
        case 14: _t->handleLastTabClosed(); break;
        case 15: _t->applySettings(); break;
        case 16: _t->applySkin(); break;
        case 17: _t->applyWindowProperties(); break;
        case 18: _t->applyWindowGeometry(); break;
        case 19: _t->setWindowGeometry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 20: _t->updateScreenMenu(); break;
        case 21: _t->setScreen((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 22: _t->setWindowWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->setWindowHeight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->setWindowWidth((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 25: _t->setWindowHeight((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 26: _t->increaseWindowWidth(); break;
        case 27: _t->decreaseWindowWidth(); break;
        case 28: _t->increaseWindowHeight(); break;
        case 29: _t->decreaseWindowHeight(); break;
        case 30: _t->wmActiveWindowChanged(); break;
        case 31: _t->xshapeOpenWindow(); break;
        case 32: _t->xshapeRetractWindow(); break;
        case 33: _t->activate(); break;
        case 34: _t->toggleMousePoll((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->pollMouse(); break;
        case 36: _t->setKeepOpen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->handleSwitchToAction(); break;
        case 38: _t->handleToggleTitlebar(); break;
        case 39: _t->whatsThis(); break;
        case 40: _t->configureKeys(); break;
        case 41: _t->configureNotifications(); break;
        case 42: _t->configureApp(); break;
        case 43: _t->updateTrayTooltip(); break;
        case 44: _t->showFirstRunDialog(); break;
        case 45: _t->firstRunDialogFinished(); break;
        case 46: _t->firstRunDialogOk(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::windowOpened, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::windowClosed, 1))
            return;
    }
}

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::windowOpened()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MainWindow::windowClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
